@@ -1,26 +1,28 @@
 #!/usr/bin/perl
 
-use strict;
+use v5.26;
 use warnings;
 
 use Device::Chip::TSL256x;
 use Device::Chip::Adapter;
 
+use Future::AsyncAwait;
+
 use Getopt::Long;
 
 GetOptions(
    'i|interval=i'   => \(my $INTERVAL = 10),
    'p|print-config' => \my $PRINT_CONFIG,
 
-   'adapter|A=s' => \( my $ADAPTER = "BusPirate" ),
+   'adapter|A=s' => \my $ADAPTER,
 ) or exit 1;
 
 my $chip = Device::Chip::TSL256x->new;
-$chip->mount(
+await $chip->mount(
    Device::Chip::Adapter->new_from_description( $ADAPTER )
-)->get;
+);
 
-$chip->protocol->power(1)->get;
+await $chip->protocol->power(1);
 
 $SIG{INT} = $SIG{TERM} = sub { exit 1; };
 
@@ -28,13 +30,13 @@ END {
    $chip and $chip->protocol->power(0)->get;
 }
 
-printf "Chip ID: %02X\n", $chip->read_id->get;
+printf "Chip ID: %02X\n", await $chip->read_id;
 
-$chip->power(1)->get;
+await $chip->power(1);
 sleep 1;
 
 if( $PRINT_CONFIG ) {
-   my $config = $chip->read_config->get;
+   my $config = await $chip->read_config;
    printf "%20s: %s\n", $_, $config->{$_} for sort keys %$config;
 }
 
@@ -42,7 +44,7 @@ my $gain = 1;
 my $smallcount;
 
 while(1) {
-   my ( $lux, $data0, $data1 ) = $chip->read_lux->get;
+   my ( $lux, $data0, $data1 ) = await $chip->read_lux;
    printf "Lux: %.2f\n", $lux;
 
    # See if we should switch up to high gain
@@ -51,7 +53,7 @@ while(1) {
       if( $smallcount >= 4 ) {
          print "Switching to GAIN=16\n";
          $gain = 16;
-         $chip->change_config( GAIN => 16 )->get;
+         await $chip->change_config( GAIN => 16 );
       }
    }
    else {
@@ -62,7 +64,7 @@ while(1) {
    if( $gain == 16 and ( $data0 > 0xff00 or $data1 > 0xff00 ) ) {
       print "Switching to GAIN=1\n";
       $gain = 1;
-      $chip->change_config( GAIN => 1 )->get;
+      await $chip->change_config( GAIN => 1 );
    }
 
    sleep $INTERVAL;
